==> org-lsst-sal-camera-2.5.0-sources.jar: org/lsst/sal/camera/event/Focal_plane_SequencerConfig_SequencerConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Focal_plane_SequencerConfig_SequencerConfigurationEvent extends CameraEvent {
  private final String version;

  private final String clearCountParameter;

  private final String clearMain;

  private final String idleFlushMain;

  private final long idleFlushTimeout;

  private final String integrateMain;

  private final String metaDataRegisters;

  private final int overCols;

  private final int overRows;

  private final int postCols;

  private final int postRows;

  private final int preCols;

  private final int preRows;

  private final String pseudoReadMain;

  private final int readCols;

  private final int readCols2;

  private final String readMain;

  private final int readRows;

  private final String rowShiftForwardMain;

  private final String rowShiftReverseMain;

  private final boolean scanMode;

  private final String sequencer;

  private final String sequencerChecksums;

  private final String shiftCountParameter;

  private final boolean stepAfterIntegrate;

  private final int transparentMode;

  private final int underCols;

  private final boolean useParallelRegisters;

  public Focal_plane_SequencerConfig_SequencerConfigurationEvent(int priority, String version,
      String clearCountParameter, String clearMain, String idleFlushMain, long idleFlushTimeout,
      String integrateMain, String metaDataRegisters, int overCols, int overRows, int postCols,
      int postRows, int preCols, int preRows, String pseudoReadMain, int readCols, int readCols2,
      String readMain, int readRows, String rowShiftForwardMain, String rowShiftReverseMain,
      boolean scanMode, String sequencer, String sequencerChecksums, String shiftCountParameter,
      boolean stepAfterIntegrate, int transparentMode, int underCols,
      boolean useParallelRegisters) {
    super (priority);
    this.version = version;
    this.clearCountParameter = clearCountParameter;
    this.clearMain = clearMain;
    this.idleFlushMain = idleFlushMain;
    this.idleFlushTimeout = idleFlushTimeout;
    this.integrateMain = integrateMain;
    this.metaDataRegisters = metaDataRegisters;
    this.overCols = overCols;
    this.overRows = overRows;
    this.postCols = postCols;
    this.postRows = postRows;
    this.preCols = preCols;
    this.preRows = preRows;
    this.pseudoReadMain = pseudoReadMain;
    this.readCols = readCols;
    this.readCols2 = readCols2;
    this.readMain = readMain;
    this.readRows = readRows;
    this.rowShiftForwardMain = rowShiftForwardMain;
    this.rowShiftReverseMain = rowShiftReverseMain;
    this.scanMode = scanMode;
    this.sequencer = sequencer;
    this.sequencerChecksums = sequencerChecksums;
    this.shiftCountParameter = shiftCountParameter;
    this.stepAfterIntegrate = stepAfterIntegrate;
    this.transparentMode = transparentMode;
    this.underCols = underCols;
    this.useParallelRegisters = useParallelRegisters;
  }

  public String getVersion() {
    return version;
  }

  public String getClearCountParameter() {
    return clearCountParameter;
  }

  public String getClearMain() {
    return clearMain;
  }

  public String getIdleFlushMain() {
    return idleFlushMain;
  }

  public long getIdleFlushTimeout() {
    return idleFlushTimeout;
  }

  public String getIntegrateMain() {
    return integrateMain;
  }

  public String getMetaDataRegisters() {
    return metaDataRegisters;
  }

  public int getOverCols() {
    return overCols;
  }

  public int getOverRows() {
    return overRows;
  }

  public int getPostCols() {
    return postCols;
  }

  public int getPostRows() {
    return postRows;
  }

  public int getPreCols() {
    return preCols;
  }

  public int getPreRows() {
    return preRows;
  }

  public String getPseudoReadMain() {
    return pseudoReadMain;
  }

  public int getReadCols() {
    return readCols;
  }

  public int getReadCols2() {
    return readCols2;
  }

  public String getReadMain() {
    return readMain;
  }

  public int getReadRows() {
    return readRows;
  }

  public String getRowShiftForwardMain() {
    return rowShiftForwardMain;
  }

  public String getRowShiftReverseMain() {
    return rowShiftReverseMain;
  }

  public boolean isScanMode() {
    return scanMode;
  }

  public String getSequencer() {
    return sequencer;
  }

  public String getSequencerChecksums() {
    return sequencerChecksums;
  }

  public String getShiftCountParameter() {
    return shiftCountParameter;
  }

  public boolean isStepAfterIntegrate() {
    return stepAfterIntegrate;
  }

  public int getTransparentMode() {
    return transparentMode;
  }

  public int getUnderCols() {
    return underCols;
  }

  public boolean isUseParallelRegisters() {
    return useParallelRegisters;
  }

  @Override
  public String toString() {
    return "Focal_plane_SequencerConfig_SequencerConfigurationEvent{" + "version=" + version +
        ", clearCountParameter=" + clearCountParameter +", clearMain=" + clearMain +
        ", idleFlushMain=" + idleFlushMain +", idleFlushTimeout=" + idleFlushTimeout +
        ", integrateMain=" + integrateMain +", metaDataRegisters=" + metaDataRegisters +
        ", overCols=" + overCols +", overRows=" + overRows +", postCols=" + postCols +
        ", postRows=" + postRows +", preCols=" + preCols +", preRows=" + preRows +
        ", pseudoReadMain=" + pseudoReadMain +", readCols=" + readCols +", readCols2=" + readCols2 +
        ", readMain=" + readMain +", readRows=" + readRows +
        ", rowShiftForwardMain=" + rowShiftForwardMain +
        ", rowShiftReverseMain=" + rowShiftReverseMain +", scanMode=" + scanMode +
        ", sequencer=" + sequencer +", sequencerChecksums=" + sequencerChecksums +
        ", shiftCountParameter=" + shiftCountParameter +
        ", stepAfterIntegrate=" + stepAfterIntegrate +", transparentMode=" + transparentMode +
        ", underCols=" + underCols +", useParallelRegisters=" + useParallelRegisters +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private String clearCountParameter;

    private String clearMain;

    private String idleFlushMain;

    private long idleFlushTimeout;

    private String integrateMain;

    private String metaDataRegisters;

    private int overCols;

    private int overRows;

    private int postCols;

    private int postRows;

    private int preCols;

    private int preRows;

    private String pseudoReadMain;

    private int readCols;

    private int readCols2;

    private String readMain;

    private int readRows;

    private String rowShiftForwardMain;

    private String rowShiftReverseMain;

    private boolean scanMode;

    private String sequencer;

    private String sequencerChecksums;

    private String shiftCountParameter;

    private boolean stepAfterIntegrate;

    private int transparentMode;

    private int underCols;

    private boolean useParallelRegisters;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder clearCountParameter(String clearCountParameter) {
      this.clearCountParameter = clearCountParameter;
      return this;
    }

    public Builder clearMain(String clearMain) {
      this.clearMain = clearMain;
      return this;
    }

    public Builder idleFlushMain(String idleFlushMain) {
      this.idleFlushMain = idleFlushMain;
      return this;
    }

    public Builder idleFlushTimeout(long idleFlushTimeout) {
      this.idleFlushTimeout = idleFlushTimeout;
      return this;
    }

    public Builder integrateMain(String integrateMain) {
      this.integrateMain = integrateMain;
      return this;
    }

    public Builder metaDataRegisters(String metaDataRegisters) {
      this.metaDataRegisters = metaDataRegisters;
      return this;
    }

    public Builder overCols(int overCols) {
      this.overCols = overCols;
      return this;
    }

    public Builder overRows(int overRows) {
      this.overRows = overRows;
      return this;
    }

    public Builder postCols(int postCols) {
      this.postCols = postCols;
      return this;
    }

    public Builder postRows(int postRows) {
      this.postRows = postRows;
      return this;
    }

    public Builder preCols(int preCols) {
      this.preCols = preCols;
      return this;
    }

    public Builder preRows(int preRows) {
      this.preRows = preRows;
      return this;
    }

    public Builder pseudoReadMain(String pseudoReadMain) {
      this.pseudoReadMain = pseudoReadMain;
      return this;
    }

    public Builder readCols(int readCols) {
      this.readCols = readCols;
      return this;
    }

    public Builder readCols2(int readCols2) {
      this.readCols2 = readCols2;
      return this;
    }

    public Builder readMain(String readMain) {
      this.readMain = readMain;
      return this;
    }

    public Builder readRows(int readRows) {
      this.readRows = readRows;
      return this;
    }

    public Builder rowShiftForwardMain(String rowShiftForwardMain) {
      this.rowShiftForwardMain = rowShiftForwardMain;
      return this;
    }

    public Builder rowShiftReverseMain(String rowShiftReverseMain) {
      this.rowShiftReverseMain = rowShiftReverseMain;
      return this;
    }

    public Builder scanMode(boolean scanMode) {
      this.scanMode = scanMode;
      return this;
    }

    public Builder sequencer(String sequencer) {
      this.sequencer = sequencer;
      return this;
    }

    public Builder sequencerChecksums(String sequencerChecksums) {
      this.sequencerChecksums = sequencerChecksums;
      return this;
    }

    public Builder shiftCountParameter(String shiftCountParameter) {
      this.shiftCountParameter = shiftCountParameter;
      return this;
    }

    public Builder stepAfterIntegrate(boolean stepAfterIntegrate) {
      this.stepAfterIntegrate = stepAfterIntegrate;
      return this;
    }

    public Builder transparentMode(int transparentMode) {
      this.transparentMode = transparentMode;
      return this;
    }

    public Builder underCols(int underCols) {
      this.underCols = underCols;
      return this;
    }

    public Builder useParallelRegisters(boolean useParallelRegisters) {
      this.useParallelRegisters = useParallelRegisters;
      return this;
    }

    public Focal_plane_SequencerConfig_SequencerConfigurationEvent build() {
      return new Focal_plane_SequencerConfig_SequencerConfigurationEvent(priority, version, clearCountParameter, clearMain, idleFlushMain, idleFlushTimeout, integrateMain, metaDataRegisters, overCols, overRows, postCols, postRows, preCols, preRows, pseudoReadMain, readCols, readCols2, readMain, readRows, rowShiftForwardMain, rowShiftReverseMain, scanMode, sequencer, sequencerChecksums, shiftCountParameter, stepAfterIntegrate, transparentMode, underCols, useParallelRegisters);
    }
  }
}

==> org-lsst-sal-camera-3.0.2-sources.jar: org/lsst/sal/camera/event/Focal_plane_SequencerConfig_SequencerConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Focal_plane_SequencerConfig_SequencerConfigurationEvent extends CameraEvent {
  private final String version;

  private final String clearCountParameter;

  private final String clearMain;

  private final String idleFlushMain;

  private final long idleFlushTimeout;

  private final String integrateMain;

  private final String metaDataRegisters;

  private final int overCols;

  private final int overRows;

  private final int postCols;

  private final int postRows;

  private final int preCols;

  private final int preRows;

  private final String pseudoReadMain;

  private final int readCols;

  private final int readCols2;

  private final String readMain;

  private final int readRows;

  private final String rowShiftForwardMain;

  private final String rowShiftReverseMain;

  private final boolean scanMode;

  private final String sequencer;

  private final String sequencerChecksums;

  private final String shiftCountParameter;

  private final boolean stepAfterIntegrate;

  private final int transparentMode;

  private final int underCols;

  private final boolean useParallelRegisters;

  public Focal_plane_SequencerConfig_SequencerConfigurationEvent(String version,
      String clearCountParameter, String clearMain, String idleFlushMain, long idleFlushTimeout,
      String integrateMain, String metaDataRegisters, int overCols, int overRows, int postCols,
      int postRows, int preCols, int preRows, String pseudoReadMain, int readCols, int readCols2,
      String readMain, int readRows, String rowShiftForwardMain, String rowShiftReverseMain,
      boolean scanMode, String sequencer, String sequencerChecksums, String shiftCountParameter,
      boolean stepAfterIntegrate, int transparentMode, int underCols,
      boolean useParallelRegisters) {
    this.version = version;
    this.clearCountParameter = clearCountParameter;
    this.clearMain = clearMain;
    this.idleFlushMain = idleFlushMain;
    this.idleFlushTimeout = idleFlushTimeout;
    this.integrateMain = integrateMain;
    this.metaDataRegisters = metaDataRegisters;
    this.overCols = overCols;
    this.overRows = overRows;
    this.postCols = postCols;
    this.postRows = postRows;
    this.preCols = preCols;
    this.preRows = preRows;
    this.pseudoReadMain = pseudoReadMain;
    this.readCols = readCols;
    this.readCols2 = readCols2;
    this.readMain = readMain;
    this.readRows = readRows;
    this.rowShiftForwardMain = rowShiftForwardMain;
    this.rowShiftReverseMain = rowShiftReverseMain;
    this.scanMode = scanMode;
    this.sequencer = sequencer;
    this.sequencerChecksums = sequencerChecksums;
    this.shiftCountParameter = shiftCountParameter;
    this.stepAfterIntegrate = stepAfterIntegrate;
    this.transparentMode = transparentMode;
    this.underCols = underCols;
    this.useParallelRegisters = useParallelRegisters;
  }

  public String getVersion() {
    return version;
  }

  public String getClearCountParameter() {
    return clearCountParameter;
  }

  public String getClearMain() {
    return clearMain;
  }

  public String getIdleFlushMain() {
    return idleFlushMain;
  }

  public long getIdleFlushTimeout() {
    return idleFlushTimeout;
  }

  public String getIntegrateMain() {
    return integrateMain;
  }

  public String getMetaDataRegisters() {
    return metaDataRegisters;
  }

  public int getOverCols() {
    return overCols;
  }

  public int getOverRows() {
    return overRows;
  }

  public int getPostCols() {
    return postCols;
  }

  public int getPostRows() {
    return postRows;
  }

  public int getPreCols() {
    return preCols;
  }

  public int getPreRows() {
    return preRows;
  }

  public String getPseudoReadMain() {
    return pseudoReadMain;
  }

  public int getReadCols() {
    return readCols;
  }

  public int getReadCols2() {
    return readCols2;
  }

  public String getReadMain() {
    return readMain;
  }

  public int getReadRows() {
    return readRows;
  }

  public String getRowShiftForwardMain() {
    return rowShiftForwardMain;
  }

  public String getRowShiftReverseMain() {
    return rowShiftReverseMain;
  }

  public boolean isScanMode() {
    return scanMode;
  }

  public String getSequencer() {
    return sequencer;
  }

  public String getSequencerChecksums() {
    return sequencerChecksums;
  }

  public String getShiftCountParameter() {
    return shiftCountParameter;
  }

  public boolean isStepAfterIntegrate() {
    return stepAfterIntegrate;
  }

  public int getTransparentMode() {
    return transparentMode;
  }

  public int getUnderCols() {
    return underCols;
  }

  public boolean isUseParallelRegisters() {
    return useParallelRegisters;
  }

  @Override
  public String toString() {
    return "Focal_plane_SequencerConfig_SequencerConfigurationEvent{" + "version=" + version +
        ", clearCountParameter=" + clearCountParameter +", clearMain=" + clearMain +
        ", idleFlushMain=" + idleFlushMain +", idleFlushTimeout=" + idleFlushTimeout +
        ", integrateMain=" + integrateMain +", metaDataRegisters=" + metaDataRegisters +
        ", overCols=" + overCols +", overRows=" + overRows +", postCols=" + postCols +
        ", postRows=" + postRows +", preCols=" + preCols +", preRows=" + preRows +
        ", pseudoReadMain=" + pseudoReadMain +", readCols=" + readCols +", readCols2=" + readCols2 +
        ", readMain=" + readMain +", readRows=" + readRows +
        ", rowShiftForwardMain=" + rowShiftForwardMain +
        ", rowShiftReverseMain=" + rowShiftReverseMain +", scanMode=" + scanMode +
        ", sequencer=" + sequencer +", sequencerChecksums=" + sequencerChecksums +
        ", shiftCountParameter=" + shiftCountParameter +
        ", stepAfterIntegrate=" + stepAfterIntegrate +", transparentMode=" + transparentMode +
        ", underCols=" + underCols +", useParallelRegisters=" + useParallelRegisters +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private String clearCountParameter;

    private String clearMain;

    private String idleFlushMain;

    private long idleFlushTimeout;

    private String integrateMain;

    private String metaDataRegisters;

    private int overCols;

    private int overRows;

    private int postCols;

    private int postRows;

    private int preCols;

    private int preRows;

    private String pseudoReadMain;

    private int readCols;

    private int readCols2;

    private String readMain;

    private int readRows;

    private String rowShiftForwardMain;

    private String rowShiftReverseMain;

    private boolean scanMode;

    private String sequencer;

    private String sequencerChecksums;

    private String shiftCountParameter;

    private boolean stepAfterIntegrate;

    private int transparentMode;

    private int underCols;

    private boolean useParallelRegisters;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder clearCountParameter(String clearCountParameter) {
      this.clearCountParameter = clearCountParameter;
      return this;
    }

    public Builder clearMain(String clearMain) {
      this.clearMain = clearMain;
      return this;
    }

    public Builder idleFlushMain(String idleFlushMain) {
      this.idleFlushMain = idleFlushMain;
      return this;
    }

    public Builder idleFlushTimeout(long idleFlushTimeout) {
      this.idleFlushTimeout = idleFlushTimeout;
      return this;
    }

    public Builder integrateMain(String integrateMain) {
      this.integrateMain = integrateMain;
      return this;
    }

    public Builder metaDataRegisters(String metaDataRegisters) {
      this.metaDataRegisters = metaDataRegisters;
      return this;
    }

    public Builder overCols(int overCols) {
      this.overCols = overCols;
      return this;
    }

    public Builder overRows(int overRows) {
      this.overRows = overRows;
      return this;
    }

    public Builder postCols(int postCols) {
      this.postCols = postCols;
      return this;
    }

    public Builder postRows(int postRows) {
      this.postRows = postRows;
      return this;
    }

    public Builder preCols(int preCols) {
      this.preCols = preCols;
      return this;
    }

    public Builder preRows(int preRows) {
      this.preRows = preRows;
      return this;
    }

    public Builder pseudoReadMain(String pseudoReadMain) {
      this.pseudoReadMain = pseudoReadMain;
      return this;
    }

    public Builder readCols(int readCols) {
      this.readCols = readCols;
      return this;
    }

    public Builder readCols2(int readCols2) {
      this.readCols2 = readCols2;
      return this;
    }

    public Builder readMain(String readMain) {
      this.readMain = readMain;
      return this;
    }

    public Builder readRows(int readRows) {
      this.readRows = readRows;
      return this;
    }

    public Builder rowShiftForwardMain(String rowShiftForwardMain) {
      this.rowShiftForwardMain = rowShiftForwardMain;
      return this;
    }

    public Builder rowShiftReverseMain(String rowShiftReverseMain) {
      this.rowShiftReverseMain = rowShiftReverseMain;
      return this;
    }

    public Builder scanMode(boolean scanMode) {
      this.scanMode = scanMode;
      return this;
    }

    public Builder sequencer(String sequencer) {
      this.sequencer = sequencer;
      return this;
    }

    public Builder sequencerChecksums(String sequencerChecksums) {
      this.sequencerChecksums = sequencerChecksums;
      return this;
    }

    public Builder shiftCountParameter(String shiftCountParameter) {
      this.shiftCountParameter = shiftCountParameter;
      return this;
    }

    public Builder stepAfterIntegrate(boolean stepAfterIntegrate) {
      this.stepAfterIntegrate = stepAfterIntegrate;
      return this;
    }

    public Builder transparentMode(int transparentMode) {
      this.transparentMode = transparentMode;
      return this;
    }

    public Builder underCols(int underCols) {
      this.underCols = underCols;
      return this;
    }

    public Builder useParallelRegisters(boolean useParallelRegisters) {
      this.useParallelRegisters = useParallelRegisters;
      return this;
    }

    public Focal_plane_SequencerConfig_SequencerConfigurationEvent build() {
      return new Focal_plane_SequencerConfig_SequencerConfigurationEvent(version, clearCountParameter, clearMain, idleFlushMain, idleFlushTimeout, integrateMain, metaDataRegisters, overCols, overRows, postCols, postRows, preCols, preRows, pseudoReadMain, readCols, readCols2, readMain, readRows, rowShiftForwardMain, rowShiftReverseMain, scanMode, sequencer, sequencerChecksums, shiftCountParameter, stepAfterIntegrate, transparentMode, underCols, useParallelRegisters);
    }
  }
}
